==> haskell-yaml-0.8.22.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.22.1
id: yaml-0.8.22.1-12E7gJJouZU1HVI6hodIEy
key: yaml-0.8.22.1-12E7gJJouZU1HVI6hodIEy
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    Please see the README.md file.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
exposed-modules:
    Text.Libyaml Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder
    Data.Yaml.Config Data.Yaml.Include Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Data.Yaml.Internal
abi: 2f73783e5eca3db86c7ba6c7210a81b2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.22.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.22.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/yaml-0.8.22.1
hs-libraries: HSyaml-0.8.22.1-12E7gJJouZU1HVI6hodIEy
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    containers-0.5.7.1 directory-1.2.6.2 filepath-1.4.1.0
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.8.22-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.22
id: yaml-0.8.22-1u74Ya7HGLsFS4A4JR4nVK
key: yaml-0.8.22-1u74Ya7HGLsFS4A4JR4nVK
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    Please see the README.md file.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
exposed-modules:
    Text.Libyaml Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder
    Data.Yaml.Config Data.Yaml.Include Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Data.Yaml.Internal
abi: 064e8abf05da92a37a38fce36ab3c450
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.22
library-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.22
data-dir: /usr/share/i386-linux-ghc-8.0.1/yaml-0.8.22
hs-libraries: HSyaml-0.8.22-1u74Ya7HGLsFS4A4JR4nVK
depends:
    aeson-1.0.2.1-12Tr6G2d7dgKxXx9Jv4gDD
    attoparsec-0.13.1.0-A4pUaeqQWkyDZOYwXw4PvN base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.9.1-GZZC8SxHl2s2gE2ucPFZOM
    containers-0.5.7.1 directory-1.2.6.2 filepath-1.4.1.0
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    scientific-0.3.4.11-ICV8fOXZrxLGwVNBrNLr5f
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
